# nixstatsagent

NixStats.com is a web service of monitoring and displaying statistics of your 
server performance.

This software is an OS-agnostic agent compatible with Python >= 2.4. 
It's been optimized to have a small CPU consumption and comes with an 
extendable set of useful plugins.
